@@ -1115,7 +1115,7 @@ elif is_server(server, 'portal'):
     elif version == 'post_pygacde':
         return_variable = '/pygacode'
     else:
-        return_variable = '/tglf_sat2'
+        return_variable = 'gacode'
 elif is_server(server, 'cori'):
     if version == 'pre_pygacode':
         raise ValueError(f'GACODE installation on {server} has not yet been updated to pre_gacode')
@@ -1149,9 +1149,11 @@ else:
                     OMFIT[module]['SETTINGS']['REMOTE_SETUP'][item]['environment'] = copy.deepcopy(
                         root['SETTINGS']['REMOTE_SETUP'][item]['environment']
                     )
-            OMFIT[module]['SETTINGS']['REMOTE_SETUP']['saturn']['executable'] = OMFIT[module]['SETTINGS']['REMOTE_SETUP']['iris'][
-                'executable'
-            ]
+
+
+#            OMFIT[module]['SETTINGS']['REMOTE_SETUP']['saturn']['executable'] = OMFIT[module]['SETTINGS']['REMOTE_SETUP']['iris'][
+#                'executable'
+#            ]
 
 
 ############################################
