@@ -94,7 +94,7 @@ def get_species(derived):
     """
     species = []
     for key in list(derived.data_vars.keys()):
-        if not re.match('^[nT](_fast)?_([0-9]+[a-zA-Z]+[0-9]|e)$', key):
+        if not re.match('^[nT](_fast)?_([0-9]+[a-zA-Z]+[0-9]{1,2}|e)$', key):
             continue
         s = key.split('_')[-1]
         if '_fast_' in key:
