@@ -1309,6 +1309,8 @@ class OMFITmaintree(OMFITproject):
         if server is None:
             printi('Reset OMFIT stored passwords')
             utils_widgets.stored_passwords.clear()
+            printi('Reset OMFIT server cache')
+            SERVER_cache.clear()
 
             if mds_cache:
                 printi('Purge OMFIT MDS+ cache')
